==> claromentis-framework-9.6.6-26891208.zip: web/intranet/infocapture/classes/FieldType.php <==
<?php
namespace Claromentis\Infocapture;

$GLOBALS["__65da1b1e" . "c2d6653e8a" . "0ab7848e53" . "6215"] = (@$GLOBALS["__65da1b1ec2d6653e8a0ab7848e536" . "215"] ?: array()) + array("_81a2dcc0860c53fed685d2" . "97849cf6b9" => base64_decode("SW52YWxpZCBmaWVsZCB0" . "eXBlIC0g"));
class FieldType
{
    
    
    
    
    
    
    
    
    
    
    
    public function Get($type)
    {
        switch ($type) {
            case \FBField::TYPE_LABEL:
                return new \FBTypeLabel();
            case \FBField::TYPE_SHORT_STRING:
                return new \FBTypeStringShort();
            case \FBField::TYPE_MEDIUM_STRING:
                return new \FBTypeStringMedium();
            case \FBField::TYPE_LONG_STRING:
                return new \FBTypeStringLong();
            case \FBField::TYPE_SHORT_TEXT:
                return new \FBTypeTextShort();
            case \FBField::TYPE_MEDIUM_TEXT:
                return new \FBTypeTextMedium();
            case \FBField::TYPE_LONG_TEXT:
                return new \FBTypeTextLong();
            case \FBField::TYPE_BBCODE_TEXT:
                return new \FBTypeTextBBCode();
            case \FBField::TYPE_RADIO:
                return new \FBTypeRadio();
            case \FBField::TYPE_SELECT:
                return new \FBTypeSelect();
            case \FBField::TYPE_GROUP:
                return new \FBTypeGroup();
            case \FBField::TYPE_ROLE:
                return new \FBTypeRole();
            case \FBField::TYPE_HTML:
                return new \FBTypeHtml();
            case \FBField::TYPE_MULTIPLE_SELECT:
                return new \FBTypeSelectMultiple();
            case \FBField::TYPE_MULTIPLE_USERLIST:
                return new \FBTypeUserlistMultiple();
            case \FBField::TYPE_DATE:
                
                
                return new \FBTypeDate();
            case \FBField::TYPE_CHECKBOX:
                return new \FBTypeCheckbox();
            case \FBField::TYPE_MULTIPLE_CHECKBOXES:
                return new \FBTypeMultipleCheckboxes();
            case \FBField::TYPE_USERLIST:
                return new \FBTypeUserlist();
            case \FBField::TYPE_DOCUMENT:
                return new \FBTypeDocument();
            case \FBField::TYPE_FILE:
                return new \FBTypeFile();
            case \FBField::TYPE_DATE_PICKER:
                return new \FBTypeDatePicker();
            case \FBField::TYPE_DATE_TIME_PICKER:
                return new \FBTypeDateTimePicker();
            case \FBField::TYPE_NOTICE:
                return new \FBTypeNotice();
            case \FBField::TYPE_SIGNATURE_PAD:
                return new \FBTypeSignaturePad();
            case \FBField::TYPE_FINANCIAL:
                return new \FBTypeFinancial();
            default:
                throw new \Exception($GLOBALS["__65da1b1ec2d6653e8a0ab784" . "8e536215"]["_81a2dcc0860c53fed685d297849cf6b" . "9"] . $type);
        }
    }
}

==> claromentis-framework-10.3.3-59629072.zip: web/intranet/infocapture/classes/FieldType.php <==
<?php
namespace Claromentis\Infocapture;

$GLOBALS["__65da1b1ec2d6653e8a0ab7848e5" . "36215"] = (@$GLOBALS["__65da1b1ec2d6653e8a0ab7848e536" . "215"] ?: array()) + array("_81a2dcc0860c53f" . "ed685d297849cf6b" . "9" => base64_decode("SW52YWxpZCBmaWVsZCB0eXB" . "lIC0g"));
class FieldType
{
    
    
    
    
    
    
    
    
    
    
    
    public function Get($type)
    {
        switch ($type) {
            case \FBField::TYPE_LABEL:
                return new \FBTypeLabel();
            case \FBField::TYPE_SHORT_STRING:
                return new \FBTypeStringShort();
            case \FBField::TYPE_MEDIUM_STRING:
                return new \FBTypeStringMedium();
            case \FBField::TYPE_LONG_STRING:
                return new \FBTypeStringLong();
            case \FBField::TYPE_SHORT_TEXT:
                return new \FBTypeTextShort();
            case \FBField::TYPE_MEDIUM_TEXT:
                return new \FBTypeTextMedium();
            case \FBField::TYPE_LONG_TEXT:
                return new \FBTypeTextLong();
            case \FBField::TYPE_BBCODE_TEXT:
                return new \FBTypeTextBBCode();
            case \FBField::TYPE_RADIO:
                return new \FBTypeRadio();
            case \FBField::TYPE_SELECT:
                return new \FBTypeSelect();
            case \FBField::TYPE_GROUP:
                return new \FBTypeGroup();
            case \FBField::TYPE_ROLE:
                return new \FBTypeRole();
            case \FBField::TYPE_HTML:
                return new \FBTypeHtml();
            case \FBField::TYPE_MULTIPLE_SELECT:
                return new \FBTypeSelectMultiple();
            case \FBField::TYPE_MULTIPLE_USERLIST:
                return new \FBTypeUserlistMultiple();
            case \FBField::TYPE_DATE:
                
                
                return new \FBTypeDate();
            case \FBField::TYPE_CHECKBOX:
                return new \FBTypeCheckbox();
            case \FBField::TYPE_MULTIPLE_CHECKBOXES:
                return new \FBTypeMultipleCheckboxes();
            case \FBField::TYPE_USERLIST:
                return new \FBTypeUserlist();
            case \FBField::TYPE_DOCUMENT:
                return new \FBTypeDocument();
            case \FBField::TYPE_FILE:
                return new \FBTypeFile();
            case \FBField::TYPE_DATE_PICKER:
                return new \FBTypeDatePicker();
            case \FBField::TYPE_DATE_TIME_PICKER:
                return new \FBTypeDateTimePicker();
            case \FBField::TYPE_NOTICE:
                return new \FBTypeNotice();
            case \FBField::TYPE_SIGNATURE_PAD:
                return new \FBTypeSignaturePad();
            case \FBField::TYPE_FINANCIAL:
                return new \FBTypeFinancial();
            default:
                throw new \Exception($GLOBALS["__65da1b1" . "ec2d6653e" . "8a0ab7848" . "e536215"]["_81a2dcc0860c53fed685d297849cf" . "6b9"] . $type);
        }
    }
}
